@@ -35,8 +35,14 @@ struct ovn_desired_flow_table {
     /* Hash map flow table using flow match conditions as hash key.*/
     struct hmap match_flow_table;
 
-    /* SB uuid index for the nodes in match_flow_table.*/
-    struct hindex uuid_flow_table;
+    /* SB uuid index for the cross reference nodes that link to the nodes in
+     * match_flow_table.*/
+    struct hmap uuid_flow_table;
+
+    /* Is flow changes tracked. */
+    bool change_tracked;
+    /* Tracked flow changes. */
+    struct ovs_list tracked_flows;
 };
 
 /* Interface for OVN main loop. */
@@ -56,8 +62,6 @@ void ofctrl_wait(void);
 void ofctrl_destroy(void);
 int64_t ofctrl_get_cur_cfg(void);
 
-struct ovn_flow *ofctrl_dup_flow(struct ovn_flow *source);
-
 void ofctrl_ct_flush_zone(uint16_t zone_id);
 
 char *ofctrl_inject_pkt(const struct ovsrec_bridge *br_int,
@@ -76,8 +80,30 @@ void ofctrl_add_or_append_flow(struct ovn_desired_flow_table *desired_flows,
                                const struct ofpbuf *actions,
                                const struct uuid *sb_uuid);
 
-void ofctrl_remove_flows(struct ovn_desired_flow_table *, const struct uuid *);
+/* Removes a bundles of flows from the flow table for a specific sb_uuid. The
+ * flows are removed only if they are not referenced by any other sb_uuid(s).
+ * For flood-removing all related flows referenced by other sb_uuid(s), use
+ * ofctrl_flood_remove_flows(). */
+void ofctrl_remove_flows(struct ovn_desired_flow_table *,
+                         const struct uuid *sb_uuid);
 
+/* The function ofctrl_flood_remove_flows flood-removes flows from the desired
+ * flow table for the sb_uuids provided in the flood_remove_nodes argument.
+ * For each given sb_uuid in flood_remove_nodes, it removes all the flows
+ * generated by the sb_uuid, and if any of the flows are referenced by another
+ * sb_uuid, it continues removing all the flows used by that sb_uuid as well,
+ * and so on, recursively.
+ *
+ * It adds all the sb_uuids that are actually removed in the
+ * flood_remove_nodes. */
+struct ofctrl_flood_remove_node {
+    struct hmap_node hmap_node;
+    struct uuid sb_uuid;
+};
+void ofctrl_flood_remove_flows(struct ovn_desired_flow_table *,
+                               struct hmap *flood_remove_nodes);
+void ofctrl_flood_remove_add_node(struct hmap *flood_remove_nodes,
+                                  const struct uuid *sb_uuid);
 void ovn_desired_flow_table_init(struct ovn_desired_flow_table *);
 void ovn_desired_flow_table_clear(struct ovn_desired_flow_table *);
 void ovn_desired_flow_table_destroy(struct ovn_desired_flow_table *);
@@ -88,6 +114,7 @@ void ofctrl_check_and_add_flow(struct ovn_desired_flow_table *,
                                const struct ofpbuf *ofpacts,
                                const struct uuid *, bool log_duplicate_flow);
 
+
 bool ofctrl_is_connected(void);
 void ofctrl_set_probe_interval(int probe_interval);
 
