@@ -903,6 +903,7 @@ get_nexthop_from_lport_addresses(int family,
                                  const struct lport_addresses *laddr,
                                  struct v46_ip *nexthop)
 {
+    memset(nexthop, 0, sizeof *nexthop);
     nexthop->family = family;
     if (family == AF_INET) {
         if (!laddr->n_ipv4_addrs) {
@@ -1575,13 +1576,9 @@ main(int argc, char *argv[])
 
     daemonize_start(false);
 
-    if (!unixctl_path) {
-        char *abs_unixctl_path = get_abs_unix_ctl_path();
-        retval = unixctl_server_create(abs_unixctl_path, &unixctl);
-        free(abs_unixctl_path);
-    } else {
-        retval = unixctl_server_create(unixctl_path, &unixctl);
-    }
+    char *abs_unixctl_path = get_abs_unix_ctl_path(unixctl_path);
+    retval = unixctl_server_create(abs_unixctl_path, &unixctl);
+    free(abs_unixctl_path);
 
     if (retval) {
         exit(EXIT_FAILURE);
