@@ -254,12 +254,6 @@ ovn_init_symtab(struct shash *symtab)
     expr_symtab_add_field(symtab, "sctp.src", MFF_SCTP_SRC, "sctp", false);
     expr_symtab_add_field(symtab, "sctp.dst", MFF_SCTP_DST, "sctp", false);
 
-    shash_init(&ovnfield_by_name);
-    for (int i = 0; i < OVN_FIELD_N_IDS; i++) {
-        const struct ovn_field *of = &ovn_fields[i];
-        ovs_assert(of->id == i); /* Fields must be in the enum order. */
-        shash_add_once(&ovnfield_by_name, of->name, of);
-    }
     expr_symtab_add_ovn_field(symtab, "icmp4.frag_mtu", OVN_ICMP4_FRAG_MTU);
 }
 
@@ -284,14 +278,35 @@ string_to_event(const char *s)
     return -1;
 }
 
-const struct ovn_field *
-ovn_field_from_name(const char *name)
-{
-    return shash_find_data(&ovnfield_by_name, name);
-}
-
-void
+static void
 ovn_destroy_ovnfields(void)
 {
     shash_destroy(&ovnfield_by_name);
 }
+
+static void
+ovn_do_init_ovnfields(void)
+{
+    shash_init(&ovnfield_by_name);
+    for (int i = 0; i < OVN_FIELD_N_IDS; i++) {
+       const struct ovn_field *of = &ovn_fields[i];
+       ovs_assert(of->id == i); /* Fields must be in the enum order. */
+       shash_add_once(&ovnfield_by_name, of->name, of);
+    }
+    atexit(ovn_destroy_ovnfields);
+}
+
+static void
+ovn_init_ovnfields(void)
+{
+    static pthread_once_t once = PTHREAD_ONCE_INIT;
+    pthread_once(&once, ovn_do_init_ovnfields);
+}
+
+const struct ovn_field *
+ovn_field_from_name(const char *name)
+{
+    ovn_init_ovnfields();
+
+    return shash_find_data(&ovnfield_by_name, name);
+}
