@@ -82,7 +82,7 @@ const char *default_nb_db(void);
 const char *default_sb_db(void);
 const char *default_ic_nb_db(void);
 const char *default_ic_sb_db(void);
-char *get_abs_unix_ctl_path(void);
+char *get_abs_unix_ctl_path(const char *path);
 
 struct ovsdb_idl_table_class;
 const char *db_table_usage(struct ds *tables,
